@@ -1,8 +1,7 @@
+from django.conf import settings
 from django.http import JsonResponse
 
-from ..conf import settings
-
 
 def get_current_user(request):
-    data = settings.current_user_serializer(request.user)
+    data = settings.DJANGOKIT.current_user_serializer(request.user)
     return JsonResponse(data)
